﻿* Encoding: UTF-8.

*Satisfaction with life scale

COMPUTE SWLS_M = MEAN(SWL_1, SWL_2, SWL_3, SWL_4, SWL_5).
EXECUTE.
VARIABLE LABELS SWLS_M 'satisfaction with life scale'.

*Status-based identity uncertainty

COMPUTE SBIU_M = MEAN(SBIU_1R, SBIU_2R, SBIU_3R, SBIU_4R, SBIU_5R, SBIU_6, SBIU_7R, SBIU_8R, SBIU_9R, SBIU_10R, SBIU_11, SBIU_12R). 
VARIABLE LABELS SBIU_M 'Status based identity uncertainty (mean)'.

*Computation of OSES*

DESCRIPTIVES VARIABLES= yed hhinc
  /SAVE.

COMPUTE OSES=MEAN.2(Zyed, Zhhinc).
EXECUTE.
VARIABLE LABELS OSES 'Objective Social Class (Mean of Zhhinc and Zyed)'.

DESCRIPTIVES VARIABLES= OSES USSES SWLS_M SBIU_M
  /SAVE.

*Correlation*

CORRELATIONS
  /VARIABLES= hhinc yed oses usses SBIU_M swls_m
  /PRINT=TWOTAIL NOSIG
  /MISSING=PAIRWISE.

*Computation of interaction term

COMPUTE int = Zoses*Zusses.
DESCRIPTIVES VARIABLES= int
  /SAVE.

*Regression*

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA CHANGE SES COLLIN TOL BCOV
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT ZSWLS_M
  /METHOD=ENTER Zusses Zoses
  /METHOD=ENTER Zint.

*Including covariate. 
*Note: For sex, the reference group is female.

REGRESSION 
  /MISSING LISTWISE 
  /STATISTICS COEFF OUTS R ANOVA CHANGE SES COLLIN TOL BCOV
  /CRITERIA=PIN(.05) POUT(.10) 
  /NOORIGIN 
  /DEPENDENT ZSWLS_M 
  /METHOD=ENTER sex 
  /METHOD=ENTER Zusses Zoses
  /METHOD=ENTER Zint.

*Analysis for two-stage moderated mediation using Edwards & Lambert (2007) methods

COMPUTE XZ = ZUSSES * ZOSES.
EXECUTE.
Variable Labels XZ 'ZUSSES * ZOSES'.

COMPUTE MZ = ZOSES * ZSBIU_M.
EXECUTE.
Variable Labels MZ 'ZOSES * ZSBIU_M'.

DESCRIPTIVES VAR= XZ MZ
/SAVE.

* REGRESSION syntax for Equation 5.
REGRESSION
 /STATISTICS COEFF OUTS BCOV R ANOVA COLLIN TOL CHANGE ZPP
/DEPENDENT ZSBIU_M
/METHOD=ENTER ZUSSES ZOSES ZXZ.

* REGRESSION syntax for Equation 10.
REGRESSION
 /STATISTICS COEFF OUTS BCOV R ANOVA COLLIN TOL CHANGE ZPP
/DEPENDENT ZSWLS_M
/METHOD=ENTER ZUSSES ZSBIU_M ZOSES ZMZ /*from Equation 10*/.

* CNLR syntax to produce bootstrap estimates for Equation 5.
SET RNG=MT MTINDEX=54321 /*Merseene Twister random number generator, seed set at 54321*/. 
MODEL PROGRAM a05=0 aX5=-.139 aZ5=-.019 aXZ5=-.145 /*Starting values for coefficients*/.
COMPUTE PRED = a05 + aX5*Zusses + aZ5*ZOSES + aXZ5*ZXZ /*Coefficients and independent variables*/. 
CNLR ZSBIU_M /*CNLR procedure, dependent variable*/
/OUTFILE=EQN05.SAV /*File for bootstrap coefficient estimates*/
/BOOTSTRAP=1000 /*Number of bootstrap samples*/.

* CNLR syntax to produce bootstrap estimates for Equation 10.
SET RNG=MT MTINDEX=54321 /*Merseene Twister random number generator, seed set at 54321*/.
MODEL PROGRAM b010=0 bX10=.357 bM10=-.011 bZ10=.183 bMZ10=-.041 /*Starting values for coefficients*/.
COMPUTE PRED = b010 + bX10*Zusses + bM10*ZSBIU_M + bZ10*ZOSES + bMZ10*ZMZ /*Coefficients and independent variables*/. 
CNLR ZSWLS_M /*CNLR procedure, dependent variable*/
/OUTFILE=EQN10.SAV /*File for bootstrap coefficient estimates*/
/BOOTSTRAP=1000 /*Number of bootstrap samples*/.


